@@ -11,20 +11,9 @@ def create_footprint(
 ):
 	logging.info("creating footprint ...")
 
-	# fetch the compoennt data for easyeda library
-	response = requests.get(
-		f"https://easyeda.com/api/components/{footprint_component_uuid}"
+	footprint_name, datasheet_link, footprint_shape = get_footprint_info(
+		footprint_component_uuid
 	)
-	if response.status_code == requests.codes.ok:
-		data = json.loads(response.content.decode())
-	else:
-		logging.error(
-			f"create_footprint error. Requests returned with error code {response.status_code}"
-		)
-		return ()
-	footprint_shape = data["result"]["dataStr"]["shape"]
-
-	footprint_name, datasheet_link, assembly_process = get_footprint_info(component_id)
 
 	# init kicad footprint
 	kicad_mod = Footprint(f'"{footprint_name}"')
@@ -38,8 +27,7 @@ def create_footprint(
 				-10000,
 				10000,
 				10000,
-			)  # I will be using these to calculate the bounding box because the node.calculateBoundingBox() methode does not seems to work for me
-			self.assembly_process = assembly_process
+			)  # I will be using these to calculate the bounding box because the node.calculateBoundingBox() method does not seems to work for me
 			self.footprint_name = footprint_name
 			self.output_dir = output_dir
 			self.footprint_lib = footprint_lib
@@ -106,68 +94,38 @@ def create_footprint(
 	return (f"{footprint_lib}:{footprint_name}", datasheet_link)
 
 
-def get_footprint_info(component_id):
+def get_footprint_info(footprint_component_uuid):
 
-	# send request to get assembly process and datasheet_link
-	request_data = """{}\"currentPage\":1,\"pageSize\":100,
-				\"keyword\":\"{}\",
-				\"searchSource\":\"search\",
-				\"componentAttributes\":[]{}"
-				""".format(
-		"{", component_id, "}"
-	)
-
-	response = requests.post(
-		url="https://jlcpcb.com/shoppingCart/smtGood/selectSmtComponentList",
-		headers={"Content-Type": "application/json;charset=utf-8"},
-		data=request_data,
+	# fetch the compoennt data for easyeda library
+	response = requests.get(
+		f"https://easyeda.com/api/components/{footprint_component_uuid}"
 	)
 
 	if response.status_code == requests.codes.ok:
-		response = json.loads(response.content.decode())
+		data = json.loads(response.content.decode())
 	else:
 		logging.error(
-			f"get_footprint_info request error. Requests returned with error code {response.status_code}"
+			f"create_footprint error. Requests returned with error code {response.status_code}"
 		)
 		return ()
 
-	footprint_name = datasheet_link = assembly_process = None
+	footprint_shape = data["result"]["dataStr"]["shape"]
+	datasheet_link = data["result"]["dataStr"]["head"]["c_para"]["link"]
 	footprint_name = (
-		response["data"]["componentPageInfo"]["list"][0]["componentModelEn"]
+		data["result"]["title"]
 		.replace(" ", "_")
 		.replace("/", "_")
+		.replace("(", "_")
+		.replace("(", "_")
 	)
 
-	component_list = response["data"]["componentPageInfo"]["list"]
-	for component in component_list:
-		if component["componentCode"] == component_id:
-			component_lcscid = component["componentId"]
-
-			response = requests.get(
-				f"https://jlcpcb.com/shoppingCart/smtGood/getComponentDetail?componentLcscId={component_lcscid}"
-			)
-			if response.status_code == requests.codes.ok:
-				component_data = json.loads(response.content.decode())["data"]
-			else:
-				logging.error(
-					f"get_footprint_info error, could not retrieve component's data. Requests returned with error code {response.status_code}"
-				)
-				return ()
-
-			datasheet_link = component_data["dataManualUrl"]
-			assembly_process = component_data["assemblyProcess"]
-			logging.debug(f"'get_footprint_info : component_data : {component_data}")
-			break
-
 	if not footprint_name:
 		footprint_name = "NoName"
 		logging.warning(
-			"Could not retrieve components information from JLCPCB, default name 'NoName'."
+			"Could not retrieve components information from EASYEDA, default name 'NoName'."
 		)
 	if not datasheet_link:
 		datasheet_link = ""
-		logging.warning("Could not retrieve datasheet link from JLCPCB")
-	if not assembly_process:
-		assembly_process = ""
+		logging.warning("Could not retrieve datasheet link from EASYEDA")
 
-	return (footprint_name, datasheet_link, assembly_process)
+	return (footprint_name, datasheet_link, footprint_shape)
